@@ -45,6 +45,10 @@ struct imp_dbh_st {
 	int     pg_enable_utf8;    /* legacy utf8 flag: force utf8 flag on or off, regardless of client_encoding */
 	bool    pg_utf8_flag;      /* are we currently flipping the utf8 flag on? */
     bool    client_encoding_utf8; /* is the client_encoding utf8 last we checked? */
+
+    PGresult  *last_result;     /* PGresult structure from the last executed query (can be from imp_dbh or imp_sth) */
+    long sth_result_owner;      /* Unique address of the sth that created it the above */
+	imp_sth_t *do_tmp_sth;      /* temporary sth to refer inside a do() call */
 };
 
 
@@ -232,6 +236,8 @@ int pg_db_putcopyend (SV * dbh);
 
 int pg_db_endcopy (SV * dbh);
 
+SV * pg_db_error_field (SV *dbh, char * fieldname);
+
 void pg_db_pg_server_trace (SV *dbh, FILE *fh);
 
 void pg_db_pg_server_untrace (SV *dbh);
