@@ -1,6 +1,6 @@
 /*
 
-   Copyright (c) 2003-2018 Greg Sabino Mullane and others: see the Changes file
+   Copyright (c) 2003-2019 Greg Sabino Mullane and others: see the Changes file
 
    You may distribute under the terms of either the GNU General Public
    License or the Artistic License, as specified in the Perl README file.
@@ -229,7 +229,7 @@ char * quote_bytea(pTHX_ char *string, STRLEN len, STRLEN *retlen, int estring)
 			*result++ = '\\';
 		}
 		else if (*string < 0x20 || *string > 0x7e) {
-			(void) snprintf((char *)result, 6, "\\\\%03o", (unsigned char)*string++);
+			(void) sprintf((char *)result, "\\\\%03o", (unsigned char)*string++);
 			result += 5;
 		}
 		else {
